@@ -1,7 +1,7 @@
-VERSION = (2, 4, 0)
-__version__ = '.'.join(map(str, VERSION))
+VERSION = (3, 1, 0)
+__version__ = ".".join(map(str, VERSION))
 
-default_app_config = 'admin_sso.apps.AdminSSOConfig'
+default_app_config = "admin_sso.apps.AdminSSOConfig"
 
 # Do not use Django settings at module level as recommended
 try:
@@ -9,9 +9,11 @@ try:
 except ImportError:
     pass
 else:
+
     class LazySettings(LazyObject):
         def _setup(self):
             from admin_sso import default_settings
+
             self._wrapped = Settings(default_settings)
 
     class Settings(object):
