@@ -11,8 +11,8 @@ class DjangoSSOAuthBackend(object):
         except cls.DoesNotExist:
             return None
 
-    def authenticate(self, request=None, **kwargs):
-        sso_email = kwargs.pop('sso_email', None)
+    def authenticate(self, request, **kwargs):
+        sso_email = kwargs.pop("sso_email", None)
 
         assignment = Assignment.objects.for_email(sso_email)
         if assignment is None:
