@@ -3,20 +3,16 @@ from __future__ import unicode_literals
 import fnmatch
 
 from django.db import models
-from django.utils.encoding import python_2_unicode_compatible
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from admin_sso import settings
 
 
 class AssignmentManager(models.Manager):
     def for_email(self, email):
-        if not email:
-            return None
-
         try:
-            username, domain = email.split('@')
-        except ValueError:
+            username, domain = email.split("@")
+        except (AttributeError, TypeError, ValueError):
             return None
         possible_assignments = self.filter(domain=domain)
         used_assignment = None
@@ -37,20 +33,20 @@ class AssignmentManager(models.Manager):
         return used_assignment
 
 
-@python_2_unicode_compatible
 class Assignment(models.Model):
     username_mode = models.IntegerField(choices=settings.ASSIGNMENT_CHOICES)
     username = models.CharField(max_length=255, blank=True)
     domain = models.CharField(max_length=255)
     copy = models.BooleanField(default=False)
     weight = models.PositiveIntegerField(default=0)
-    user = models.ForeignKey(settings.AUTH_USER_MODEL, null=True, blank=True,
-                             on_delete=models.CASCADE)
+    user = models.ForeignKey(
+        settings.AUTH_USER_MODEL, null=True, blank=True, on_delete=models.CASCADE
+    )
 
     class Meta:
-        ordering = ('-weight',)
-        verbose_name = _('Assignment')
-        verbose_name_plural = _('Assignments')
+        ordering = ("-weight",)
+        verbose_name = _("Assignment")
+        verbose_name_plural = _("Assignments")
 
     def __str__(self):
         return "%s(%s) @%s" % (
